==> ejc-salary-impl-3.0.0-20241017.065649-32-sources.jar: com/ejianc/business/salary/bean/JspayableDetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资计算明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_detail")
public class JspayableDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_id")
    private Long jspayableId; // 主表id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="detail_org_id")
    private Long detailOrgId; // 单位id
    @TableField(value="detail_org_name")
    private String detailOrgName; // 单位名称
    @TableField(value="detail_org_code")
    private String detailOrgCode; // 单位编码
    @TableField(value="job_type")
    private String jobType; // 岗位性质
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="dept")
    private String dept; // 部门
    @TableField(value="job_level")
    private String jobLevel; // 岗级
    @TableField(value="sbjn_org_name")
    private String sbjnOrgName; // 社保缴纳单位名称
    @TableField(value="sbjn_org_code")
    private String sbjnOrgCode; // 社保缴纳单位编码
    @TableField(value="need_attendance_days")
    private BigDecimal needAttendanceDays; // 应出勤天数
    @TableField(value="actual_attendance_days")
    private BigDecimal actualAttendanceDays; // 实际出勤天数
    @TableField(value="is_move")
    private String isMove; // 本月是否发生调动：1是,2-否
    @TableField(value="sbcd_bill_id")
    private Long sbcdBillId; // 社保承担主单据id
    @TableField(value="sbcd_bill_name")
    private String sbcdBillName; // 社保承担单位名称
    @TableField(value="is_adjust")
    private String isAdjust; // 公积金调整修改记录：1是,2-否
    @TableField(value="un_write_off_mny")
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    @TableField(value="write_off_mny")
    private BigDecimal writeOffMny; // 本次核销金额
    @TableField(value="yfjs_mny")
    private BigDecimal yfjsMny; // 应发计税
    @TableField(value="yfms_mny")
    private BigDecimal yfmsMny; // 应发免税
    @TableField(value="job_mny")
    private BigDecimal jobMny; // 岗位工资
    @TableField(value="performance_mny")
    private BigDecimal performanceMny; // 绩效工资
    @TableField(value="work_year_mny")
    private BigDecimal workYearMny; // 司龄补贴
    @TableField(value="work_type_mny")
    private BigDecimal workTypeMny; // 职称补贴
    @TableField(value="certificate_mny")
    private BigDecimal certificateMny; // 证书补贴
    @TableField(value="travel_mny")
    private BigDecimal travelMny; // 派驻补贴
    @TableField(value="traffic_mny")
    private BigDecimal trafficMny; // 交通补贴
    @TableField(value="meal_mny")
    private BigDecimal mealMny; // 餐补
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 福利费
    @TableField(value="holiday_mny")
    private BigDecimal holidayMny; // 过节费
    @TableField(value="year_end_mny")
    private BigDecimal yearEndMny; // 年终奖
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="add_mny")
    private BigDecimal addMny; // 补款
    @TableField(value="button_mny")
    private BigDecimal buttonMny; // 扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 工资合计
    @TableField(value="yf_salary_mny")
    private BigDecimal yfSalaryMny; // 应发工资
    @TableField(value="yfms_salary_mny")
    private BigDecimal yfmsSalaryMny; // 应发+免税
    @TableField(value="critical_illness_mny")
    private BigDecimal criticalIllnessMny; // 大病医保
    @TableField(value="person_endowment_mny")
    private BigDecimal personEndowmentMny; // 个人养老金额
    @TableField(value="person_medical_mny")
    private BigDecimal personMedicalMny; // 个人医疗金额
    @TableField(value="person_unemployment_mny")
    private BigDecimal personUnemploymentMny; // 个人失业金额
    @TableField(value="person_house_mny")
    private BigDecimal personHouseMny; // 个人公积金
    @TableField(value="company_endowment_mny")
    private BigDecimal companyEndowmentMny; // 公司养老金额
    @TableField(value="company_medical_mny")
    private BigDecimal companyMedicalMny; // 公司医疗金额
    @TableField(value="company_unemployment_mny")
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    @TableField(value="company_birth_mny")
    private BigDecimal companyBirthMny; // 公司生育金额
    @TableField(value="company_injure_mny")
    private BigDecimal companyInjureMny; // 公司工伤金额
    @TableField(value="company_house_mny")
    private BigDecimal companyHouseMny; // 公司公积金
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="union_id")
    private Long unionId; // 薪资来源
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码
    
    

    public Long getJspayableId() {
        return jspayableId;
    }

    public void setJspayableId(Long jspayableId) {
        this.jspayableId = jspayableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public BigDecimal getNeedAttendanceDays() {
        return needAttendanceDays;
    }

    public void setNeedAttendanceDays(BigDecimal needAttendanceDays) {
        this.needAttendanceDays = needAttendanceDays;
    }
    public BigDecimal getActualAttendanceDays() {
        return actualAttendanceDays;
    }

    public void setActualAttendanceDays(BigDecimal actualAttendanceDays) {
        this.actualAttendanceDays = actualAttendanceDays;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdBillId() {
        return sbcdBillId;
    }

    public void setSbcdBillId(Long sbcdBillId) {
        this.sbcdBillId = sbcdBillId;
    }
    public String getSbcdBillName() {
        return sbcdBillName;
    }

    public void setSbcdBillName(String sbcdBillName) {
        this.sbcdBillName = sbcdBillName;
    }
    public String getIsAdjust() {
        return isAdjust;
    }

    public void setIsAdjust(String isAdjust) {
        this.isAdjust = isAdjust;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getUnionId() {
        return unionId;
    }

    public void setUnionId(Long unionId) {
        this.unionId = unionId;
    }

    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }

    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }

    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
}

==> ejc-salary-impl-3.0.0-20241025.030859-53-sources.jar: com/ejianc/business/salary/bean/JspayableDetailEntity.java <==
package com.ejianc.business.salary.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 应发工资计算明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_salary_jspayable_detail")
public class JspayableDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="jspayable_id")
    private Long jspayableId; // 主表id
    @TableField(value="detail_employee_id")
    private Long detailEmployeeId; // 员工主键
    @TableField(value="detail_employee_name")
    private String detailEmployeeName; // 员工名称
    @TableField(value="detail_employee_code")
    private String detailEmployeeCode; // 员工编码
    @TableField(value="id_card")
    private String idCard; // 证件号码
    @TableField(value="detail_org_id")
    private Long detailOrgId; // 单位id
    @TableField(value="detail_org_name")
    private String detailOrgName; // 单位名称
    @TableField(value="detail_org_code")
    private String detailOrgCode; // 单位编码
    @TableField(value="job_type")
    private String jobType; // 岗位性质
    @TableField(value="job")
    private String job; // 岗位
    @TableField(value="dept")
    private String dept; // 部门
    @TableField(value="job_level")
    private String jobLevel; // 岗级
    @TableField(value="sbjn_org_name")
    private String sbjnOrgName; // 社保缴纳单位名称
    @TableField(value="sbjn_org_code")
    private String sbjnOrgCode; // 社保缴纳单位编码
    @TableField(value="need_attendance_days")
    private BigDecimal needAttendanceDays; // 应出勤天数
    @TableField(value="actual_attendance_days")
    private BigDecimal actualAttendanceDays; // 实际出勤天数
    @TableField(value="is_move")
    private String isMove; // 本月是否发生调动：1是,2-否
    @TableField(value="sbcd_bill_id")
    private Long sbcdBillId; // 社保承担主单据id
    @TableField(value="sbcd_bill_name")
    private String sbcdBillName; // 社保承担单位名称
    @TableField(value="is_adjust")
    private String isAdjust; // 公积金调整修改记录：1是,2-否
    @TableField(value="un_write_off_mny")
    private BigDecimal unWriteOffMny; // 截止当前未核销金额
    @TableField(value="write_off_mny")
    private BigDecimal writeOffMny; // 本次核销金额
    @TableField(value="yfjs_mny")
    private BigDecimal yfjsMny; // 应发计税
    @TableField(value="yfms_mny")
    private BigDecimal yfmsMny; // 应发免税
    @TableField(value="job_mny")
    private BigDecimal jobMny; // 岗位工资
    @TableField(value="performance_mny")
    private BigDecimal performanceMny; // 绩效工资
    @TableField(value="work_year_mny")
    private BigDecimal workYearMny; // 司龄补贴
    @TableField(value="work_type_mny")
    private BigDecimal workTypeMny; // 职称补贴
    @TableField(value="certificate_mny")
    private BigDecimal certificateMny; // 证书补贴
    @TableField(value="travel_mny")
    private BigDecimal travelMny; // 派驻补贴
    @TableField(value="traffic_mny")
    private BigDecimal trafficMny; // 交通补贴
    @TableField(value="meal_mny")
    private BigDecimal mealMny; // 餐补
    @TableField(value="benefit_mny")
    private BigDecimal benefitMny; // 福利费
    @TableField(value="holiday_mny")
    private BigDecimal holidayMny; // 过节费
    @TableField(value="year_end_mny")
    private BigDecimal yearEndMny; // 年终奖
    @TableField(value="overtime_mny")
    private BigDecimal overtimeMny; // 加班费
    @TableField(value="add_mny")
    private BigDecimal addMny; // 补款
    @TableField(value="button_mny")
    private BigDecimal buttonMny; // 扣款
    @TableField(value="salary_mny")
    private BigDecimal salaryMny; // 工资合计
    @TableField(value="yf_salary_mny")
    private BigDecimal yfSalaryMny; // 应发工资
    @TableField(value="yfms_salary_mny")
    private BigDecimal yfmsSalaryMny; // 应发+免税
    @TableField(value="critical_illness_mny")
    private BigDecimal criticalIllnessMny; // 大病医保
    @TableField(value="person_endowment_mny")
    private BigDecimal personEndowmentMny; // 个人养老金额
    @TableField(value="person_medical_mny")
    private BigDecimal personMedicalMny; // 个人医疗金额
    @TableField(value="person_unemployment_mny")
    private BigDecimal personUnemploymentMny; // 个人失业金额
    @TableField(value="person_house_mny")
    private BigDecimal personHouseMny; // 个人公积金
    @TableField(value="company_endowment_mny")
    private BigDecimal companyEndowmentMny; // 公司养老金额
    @TableField(value="company_medical_mny")
    private BigDecimal companyMedicalMny; // 公司医疗金额
    @TableField(value="company_unemployment_mny")
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    @TableField(value="company_birth_mny")
    private BigDecimal companyBirthMny; // 公司生育金额
    @TableField(value="company_injure_mny")
    private BigDecimal companyInjureMny; // 公司工伤金额
    @TableField(value="company_house_mny")
    private BigDecimal companyHouseMny; // 公司公积金
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="union_id")
    private Long unionId; // 薪资来源
    @TableField(value="sbcd_org_id")
    private Long sbcdOrgId; // 社保承担单位id
    @TableField(value="sbcd_org_name")
    private String sbcdOrgName; // 社保承担单位名称
    @TableField(value="sbcd_org_code")
    private String sbcdOrgCode; // 社保承担单位编码

    @TableField(value="source_type")
    private String sourceType; // 来源类型 1-汇总 2-新增


    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public Long getJspayableId() {
        return jspayableId;
    }

    public void setJspayableId(Long jspayableId) {
        this.jspayableId = jspayableId;
    }
    public Long getDetailEmployeeId() {
        return detailEmployeeId;
    }

    public void setDetailEmployeeId(Long detailEmployeeId) {
        this.detailEmployeeId = detailEmployeeId;
    }
    public String getDetailEmployeeName() {
        return detailEmployeeName;
    }

    public void setDetailEmployeeName(String detailEmployeeName) {
        this.detailEmployeeName = detailEmployeeName;
    }
    public String getDetailEmployeeCode() {
        return detailEmployeeCode;
    }

    public void setDetailEmployeeCode(String detailEmployeeCode) {
        this.detailEmployeeCode = detailEmployeeCode;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }
    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }
    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }
    public String getJobType() {
        return jobType;
    }

    public void setJobType(String jobType) {
        this.jobType = jobType;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getDept() {
        return dept;
    }

    public void setDept(String dept) {
        this.dept = dept;
    }
    public String getJobLevel() {
        return jobLevel;
    }

    public void setJobLevel(String jobLevel) {
        this.jobLevel = jobLevel;
    }
    public String getSbjnOrgName() {
        return sbjnOrgName;
    }

    public void setSbjnOrgName(String sbjnOrgName) {
        this.sbjnOrgName = sbjnOrgName;
    }
    public String getSbjnOrgCode() {
        return sbjnOrgCode;
    }

    public void setSbjnOrgCode(String sbjnOrgCode) {
        this.sbjnOrgCode = sbjnOrgCode;
    }
    public BigDecimal getNeedAttendanceDays() {
        return needAttendanceDays;
    }

    public void setNeedAttendanceDays(BigDecimal needAttendanceDays) {
        this.needAttendanceDays = needAttendanceDays;
    }
    public BigDecimal getActualAttendanceDays() {
        return actualAttendanceDays;
    }

    public void setActualAttendanceDays(BigDecimal actualAttendanceDays) {
        this.actualAttendanceDays = actualAttendanceDays;
    }
    public String getIsMove() {
        return isMove;
    }

    public void setIsMove(String isMove) {
        this.isMove = isMove;
    }
    public Long getSbcdBillId() {
        return sbcdBillId;
    }

    public void setSbcdBillId(Long sbcdBillId) {
        this.sbcdBillId = sbcdBillId;
    }
    public String getSbcdBillName() {
        return sbcdBillName;
    }

    public void setSbcdBillName(String sbcdBillName) {
        this.sbcdBillName = sbcdBillName;
    }
    public String getIsAdjust() {
        return isAdjust;
    }

    public void setIsAdjust(String isAdjust) {
        this.isAdjust = isAdjust;
    }
    public BigDecimal getUnWriteOffMny() {
        return unWriteOffMny;
    }

    public void setUnWriteOffMny(BigDecimal unWriteOffMny) {
        this.unWriteOffMny = unWriteOffMny;
    }
    public BigDecimal getWriteOffMny() {
        return writeOffMny;
    }

    public void setWriteOffMny(BigDecimal writeOffMny) {
        this.writeOffMny = writeOffMny;
    }
    public BigDecimal getYfjsMny() {
        return yfjsMny;
    }

    public void setYfjsMny(BigDecimal yfjsMny) {
        this.yfjsMny = yfjsMny;
    }
    public BigDecimal getYfmsMny() {
        return yfmsMny;
    }

    public void setYfmsMny(BigDecimal yfmsMny) {
        this.yfmsMny = yfmsMny;
    }
    public BigDecimal getJobMny() {
        return jobMny;
    }

    public void setJobMny(BigDecimal jobMny) {
        this.jobMny = jobMny;
    }
    public BigDecimal getPerformanceMny() {
        return performanceMny;
    }

    public void setPerformanceMny(BigDecimal performanceMny) {
        this.performanceMny = performanceMny;
    }
    public BigDecimal getWorkYearMny() {
        return workYearMny;
    }

    public void setWorkYearMny(BigDecimal workYearMny) {
        this.workYearMny = workYearMny;
    }
    public BigDecimal getWorkTypeMny() {
        return workTypeMny;
    }

    public void setWorkTypeMny(BigDecimal workTypeMny) {
        this.workTypeMny = workTypeMny;
    }
    public BigDecimal getCertificateMny() {
        return certificateMny;
    }

    public void setCertificateMny(BigDecimal certificateMny) {
        this.certificateMny = certificateMny;
    }
    public BigDecimal getTravelMny() {
        return travelMny;
    }

    public void setTravelMny(BigDecimal travelMny) {
        this.travelMny = travelMny;
    }
    public BigDecimal getTrafficMny() {
        return trafficMny;
    }

    public void setTrafficMny(BigDecimal trafficMny) {
        this.trafficMny = trafficMny;
    }
    public BigDecimal getMealMny() {
        return mealMny;
    }

    public void setMealMny(BigDecimal mealMny) {
        this.mealMny = mealMny;
    }
    public BigDecimal getBenefitMny() {
        return benefitMny;
    }

    public void setBenefitMny(BigDecimal benefitMny) {
        this.benefitMny = benefitMny;
    }
    public BigDecimal getHolidayMny() {
        return holidayMny;
    }

    public void setHolidayMny(BigDecimal holidayMny) {
        this.holidayMny = holidayMny;
    }
    public BigDecimal getYearEndMny() {
        return yearEndMny;
    }

    public void setYearEndMny(BigDecimal yearEndMny) {
        this.yearEndMny = yearEndMny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getAddMny() {
        return addMny;
    }

    public void setAddMny(BigDecimal addMny) {
        this.addMny = addMny;
    }
    public BigDecimal getButtonMny() {
        return buttonMny;
    }

    public void setButtonMny(BigDecimal buttonMny) {
        this.buttonMny = buttonMny;
    }
    public BigDecimal getSalaryMny() {
        return salaryMny;
    }

    public void setSalaryMny(BigDecimal salaryMny) {
        this.salaryMny = salaryMny;
    }
    public BigDecimal getYfSalaryMny() {
        return yfSalaryMny;
    }

    public void setYfSalaryMny(BigDecimal yfSalaryMny) {
        this.yfSalaryMny = yfSalaryMny;
    }
    public BigDecimal getYfmsSalaryMny() {
        return yfmsSalaryMny;
    }

    public void setYfmsSalaryMny(BigDecimal yfmsSalaryMny) {
        this.yfmsSalaryMny = yfmsSalaryMny;
    }
    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }
    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }
    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }
    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }
    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }
    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }
    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }
    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }
    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }
    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }
    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getUnionId() {
        return unionId;
    }

    public void setUnionId(Long unionId) {
        this.unionId = unionId;
    }

    public Long getSbcdOrgId() {
        return sbcdOrgId;
    }

    public void setSbcdOrgId(Long sbcdOrgId) {
        this.sbcdOrgId = sbcdOrgId;
    }

    public String getSbcdOrgName() {
        return sbcdOrgName;
    }

    public void setSbcdOrgName(String sbcdOrgName) {
        this.sbcdOrgName = sbcdOrgName;
    }

    public String getSbcdOrgCode() {
        return sbcdOrgCode;
    }

    public void setSbcdOrgCode(String sbcdOrgCode) {
        this.sbcdOrgCode = sbcdOrgCode;
    }
}
